#
# spec file for package ibus-libpinyin
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2019 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-libpinyin
Version:        1.11.1
Release:        lp151.2.6.1
Summary:        Intelligent Pinyin engine based on libpinyin for IBus
License:        GPL-2.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/libpinyin/ibus-libpinyin
Source0:        http://downloads.sourceforge.net/libpinyin/ibus-libpinyin/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gnome-common
BuildRequires:  ibus-devel >= 1.4.99
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  opencc-devel >= 1.0.0
BuildRequires:  pkgconfig
BuildRequires:  sqlite3
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(libpinyin) >= 2.2.1
Requires:       python3-xdg
Provides:       locale(ibus:zh_CN;zh_SG)
%{ibus_requires}
%if 0%{?suse_version} <= 1320
BuildRequires:  lua51-devel
%else
BuildRequires:  pkgconfig(lua)
%endif

%description
It includes a Chinese Pinyin input method and a Chinese ZhuYin (Bopomofo) input method based on libpinyin for IBus.

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure --disable-static \
           --enable-opencc \
           --disable-boost \
           --enable-lua \
           --libexecdir=%{_libdir}/ibus \
           --libdir=%{_libdir} \
           --with-python=python3

make %{?_smp_mflags}

%install
%make_install

%fdupes %{buildroot}
%find_lang %{name}

%suse_update_desktop_file ibus-setup-libpinyin Utility DesktopUtility System
%suse_update_desktop_file ibus-setup-libbopomofo Utility DesktopUtility System

%fdupes %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root)
%license COPYING
%doc AUTHORS README
%{_libdir}/ibus/ibus-engine-libpinyin
%{_libdir}/ibus/ibus-setup-libpinyin
%{_datadir}/applications/ibus-setup-libbopomofo.desktop
%{_datadir}/applications/ibus-setup-libpinyin.desktop
%{_datadir}/%{name}/base.lua
%{_datadir}/%{name}/user.lua
%{_datadir}/%{name}/db/english.db
%dir %{_datadir}/appdata
%{_datadir}/appdata/libpinyin.appdata.xml
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/db
%{_datadir}/%{name}/icons
%{_datadir}/%{name}/setup
%{_datadir}/%{name}/db/strokes.db
%{_datadir}/ibus
%{_datadir}/glib-2.0/schemas/com.github.libpinyin.ibus-libpinyin.gschema.xml

%changelog
* Wed Sep  4 2019 Cliff Zhao <qzhao@suse.com>
- Porting 1.11.1 to SLE:
  * Add emoji-candidate option (boo#1112998)
  * Fix SuggestionEditor
  * Fix emoji appears in updateCandidates method(boo#1112998).
* Fri May 31 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.11.1
  * Use gettext
  * Add emoji-candidate option (boo#1112998)
  * Fix SuggestionEditor
* Thu Feb 14 2019 hillwood@opensuse.org
- Update version to 1.11.0
  * Fix keypad decimal
  * Fix emoji candidates
  * Support configurable opencc config
- Drop ibus-libpinyin-fix-build-fault.patch, merged by upstream.
* Fri Nov 30 2018 qzhao@suse.com
- Update ibus-libpinyin.spec: To adapt to tumbleweed's update to
  python3.
* Mon Nov 19 2018 qzhao@suse.com
- Modify ibus-libpinyin.spec: Add python3 compile condition to
  avoid ibus-libpinyin-setup crash in Tumbleweed's mixed
  environment(boo#1116485).
* Sat Nov 17 2018 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.10.92
  * Fixes Enter handling
* Tue Nov 13 2018 qzhao@suse.com
- Add ibus-libpinyin-fix-build-fault.patch: fix build error for
  edition 1.10 in openSUSE-Leap-15(boo#1115778).
* Fri Oct 12 2018 hillwood@opensuse.org
- Update version to 1.10.91
  * Support ime.register_trigger in lua extension
  * Support predicted candidates
  * Support emoji input
* Mon May 21 2018 hillwood@opensuse.org
- Update version to 1.10.0
  * bug fixes
* Wed Mar 14 2018 hillwood@opensuse.org
- Drop ibus-libpinyin-build_lua_5.2.patch, merged by upstream.
* Mon Mar  5 2018 hillwood@opensuse.org
- Update version to 1.9.3
  * Translate input method name in ibus menu
  * Remove phrases.txt
* Thu Sep 28 2017 hillwood@opensuse.org
- Update to 1.9.2
  * fixes pinyin and bopomofo config
* Tue Aug 29 2017 hillwood@opensuse.org
- Update to 1.9.1
  * add sort candidate option to setup dialog
* Tue Aug 22 2017 hillwood@opensuse.org
- Update to 1.9.0
  * change dconf key name to lower case
  * use libpinyin 1.9.91
  * fixes config in setup dialog
* Fri Sep  9 2016 hillwood@opensuse.org
- Update to 1.8.0
  * use libpinyin 1.6.0
* Thu Aug 11 2016 hillwood@opensuse.org
- Fix lua build on openSUSE leap.
  * add ibus-libpinyin-build_lua_5.2.patch
* Wed Aug 10 2016 hillwood@opensuse.org
- Update to 1.7.92
  * use ibus 1.5.11
  * use libpinyin 1.5.92
  * work around getLookupCursor
* Fri Dec 25 2015 i@marguerite.su
- update version 1.7.4
  * use pinyin_in_chewing_keyboard method
  * fixes m_bopomofo_keyboard_mapping option
- changes in version 1.7.3
  * use libpinyin 1.2.91
  * add Catalan
  * fix for lua 5.2 API change (luaL_register is deprecated)
  * update clearPinyinUserData method
  * update m_dictionaries
  * use pinyin_load_addon_phrase_library function
  * update setup dialog
* Wed Sep 30 2015 hillwood@opensuse.org
- Update tp 1.7.2
  * Fix for Lua 5.2 API change (luaL_register is deprecated)
  * update po files
  * update clearPinyinUserData method
  * update m_dictionaries
  * use pinyin_load_addon_phrase_library function
  * update setup dialog
  * fixes a typo
  * add libpinyin.appdata.xml
- Fix boo#947676
* Wed Apr  8 2015 hillwood@linuxfans.org
- Update to 1.7.1
  * select the first item in shortcut editor
  * fixes shortcut keys in setup dialog
  * fixes default values
* Fri Feb 20 2015 hillwood@linuxfans.org
- Fix Requires error.
* Sun Feb 15 2015 hillwood@linuxfans.org
- Update to 1.6.99.20150203
  * update class LibPinyinConfig to support export user phrases
  * update setup dialog UI
  * write exportPinyinDictionary method
  * use opencc 1.0
* Fri Feb 28 2014 hillwood@linuxfans.org
- update to 1.6.92
  * minor bug fixes
* Wed Oct 30 2013 hillwood@linuxfans.org
- add python-xdg as Requires
* Fri Jul 12 2013 hillwood@linuxfans.org
- enable lua support
- bring it as default in DVD, add Provides tag
* Mon Jul  8 2013 hillwood@linuxfans.org
- update to 1.6.91
  * update libpinyin requires
* Sun Apr 28 2013 hillwood@linuxfans.org
- update to 1.5.92
  * fixes setup dialog
  * change config key name
  * add using namespace pinyin
  * remove special phrases
  * re-factor ExtEditor
  * update base.lua
  * fixes download url in bus-libpinyin.spec.in
  * fixes getLookupCursor
  * update main2.py
  * update po files
  * polish UI
  * and more ..
* Sun Jan 27 2013 hillwood@linuxfans.org
- update to 1.4.93.
  * detect libpinyin datadir
  * fixes bopomofo icon
  * fixes ';' in double pinyin
  * add symbol to libpinyin.xml.in.in
  * add libpinyin depends
  * fixes automake
* Mon Jul 16 2012 hillwood@linuxfans.org
- update to 1.4.91，the first release of 1.5.x series.
- Add new options to setup dialog
* Mon Jul 16 2012 hillwood@linuxfans.org
- update to 1.4.1
  * fixes fillLookupTableByPage
* Thu Jul  5 2012 hillwood@linuxfans.org
- add a requires package, opencc is needed by ibus-libpinyin
* Sun Jul  1 2012 hillwood@linuxfans.org
- add a .desktop file
* Sun Jul  1 2012 hillwood@linuxfans.org
- enable opencc support
* Fri Jun 22 2012 hillwood@linuxfans.org
- Initial package from ibus-libpinyin git, version 1.4.0.20120612
